==> emodpy_covid-0.0.30-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_close_schools.py <==
#!/usr/bin/python

import json
import sqlite3
import copy
import random
from pathlib import Path
from . import schema_to_class as s2c

school_closure_timestep = 30
min_school_id = 1
max_school_id = 21
school_closure_duration = 60

def app( timestep ):

    #if Path('school_closure.json').exists():
    #    return "" 
    actual_intervention_name = "RouteAwareSimpleVaccine"
    efficacy_profile = "WaningEffectBox"
    co_event = "SchoolClosure"

    # Pretty good boilerplate starts here
    # 1) Gets
    event = s2c.get_default_campaign_event() 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" ) 
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    # Going to use MultiIntervention to distribute intervention and event
    intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    actual_intervention = s2c.get_class_with_defaults( actual_intervention_name ) 
    waning = s2c.get_class_with_defaults( efficacy_profile )
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    # 2) Hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    actual_intervention.Waning_Config = waning 
    intervention.Intervention_List = [ actual_intervention, bcast_intervention ]
    bcast_intervention.Broadcast_Event = co_event
    # ... and boilerplate ends here. This could be standard

    # WHAT?
    actual_intervention.Vaccine_Type = "Generic"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    # HOW MUCH?
    waning.Initial_Effect = 0.99
    # HOW LONG?
    waning.Box_Duration = school_closure_duration
    # WHEN?
    if timestep == -1:
        timestep = school_closure_timestep

    campaign = {}
    campaign["Events"] = []
    # WHO
    for prop_id in range( min_school_id, max_school_id ):
        new_coord = s2c.ReadOnlyDict( copy.deepcopy( json.loads(json.dumps(event.Event_Coordinator_Config))) );
        prop = []
        prop.append( "Primary:" + str( prop_id ) )
        new_coord.Property_Restrictions = prop
        new_event = s2c.get_default_campaign_event()
        new_event.Start_Day = float(timestep)
        new_event.Event_Coordinator_Config = new_coord
        campaign["Events"].append( new_event )
    new_camp_filename = "school_closure.json" 
    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file )
    return new_camp_filename

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_close_schools.py <==
#!/usr/bin/python

import json
import sqlite3
import copy
import random
from pathlib import Path
from . import schema_to_class as s2c

school_closure_timestep = 30
min_school_id = 1
max_school_id = 21
school_closure_duration = 60
debug = False
"""
school_closure_timestep: default = 30. Only used if timestep passed in is -1.
min_school_id: the minimum of the group ids for schools. Defaults to 1.
max_school_id: the maximum of the group ids for schools. Defaults to 21, but that is very much dependent on your configuration.
school_closure_duration: the duration of the school closure. It is completely relaxed after this. Defaults to 60.
debug = False
"""

def app( timestep ):

    #if Path('school_closure.json').exists():
    #    return "" 
    actual_intervention_name = "RouteAwareSimpleVaccine"
    efficacy_profile = "WaningEffectBox"
    co_event = "SchoolClosure"

    # Pretty good boilerplate starts here
    # 1) Gets
    event = s2c.get_default_campaign_event() 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" ) 
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    # Going to use MultiIntervention to distribute intervention and event
    intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    actual_intervention = s2c.get_class_with_defaults( actual_intervention_name ) 
    waning = s2c.get_class_with_defaults( efficacy_profile )
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    # 2) Hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    actual_intervention.Waning_Config = waning 
    intervention.Intervention_List = [ actual_intervention, bcast_intervention ]
    bcast_intervention.Broadcast_Event = co_event
    # ... and boilerplate ends here. This could be standard

    # WHAT?
    actual_intervention.Vaccine_Type = "Generic"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    actual_intervention.Intervention_Name = co_event
    actual_intervention.Duplicate_Policy = "Replace"

    # HOW MUCH?
    waning.Initial_Effect = 0.99
    # HOW LONG?
    waning.Box_Duration = school_closure_duration
    # WHEN?
    if timestep == -1:
        timestep = school_closure_timestep

    coordinator.finalize()
    intervention.finalize()
    actual_intervention.finalize()
    bcast_intervention.finalize()
    waning.finalize()

    campaign = {}
    campaign["Events"] = []
    # WHO
    for prop_id in range( min_school_id, max_school_id + 1 ):
        new_coord = s2c.ReadOnlyDict( copy.deepcopy( json.loads(json.dumps(event.Event_Coordinator_Config))) );
        prop = []
        prop.append( "Primary:" + str( prop_id ) )
        new_coord.Property_Restrictions = prop
        new_event = s2c.get_default_campaign_event()
        new_event.Start_Day = float(timestep)
        new_event.Event_Coordinator_Config = new_coord
        campaign["Events"].append( new_event )
    new_camp_filename = "school_closure"
    if debug:
        new_camp_filename += "_" + str(timestep)
    new_camp_filename += ".json" 
    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return new_camp_filename
